for my $i (1 .. 4) {
    1; # need a line here
}

for my $j (1 .. 5) {
    1; # need a line here
}

for my $k (1 .. 9) {
    1; # need a line here
}

$DB::single = 1;

1; # to avoid exiting
